/*******************************************************************************
 * Source File: PojoAspect.java
 ******************************************************************************/
package edu.utah.further.examples.fuse_aop;

import org.aspectj.lang.JoinPoint;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.beans.factory.InitializingBean;

/**
 * A simple POJO AOP advisor.
 * <p>
 * -----------------------------------------------------------------------------------<br>
 * (c) 2008-2009 FURTHeR Project, Health Sciences IT, University of Utah<br>
 * Contact: Dr. Scott Narus {@code <scott.narus@hsc.utah.edu>}<br>
 * Biomedical Informatics, 26 South 2000 East<br>
 * Room 5775 HSEB, Salt Lake City, UT 84112<br>
 * Day Phone: 1-801-213-3288<br>
 * -----------------------------------------------------------------------------------
 *
 * @author Oren E. Livne {@code <oren.livne@utah.edu>}</code>
 * @version Aug 4, 2009
 */
public class PojoAspect implements InitializingBean, DisposableBean
{
	// ========================= CONSTANTS =================================

	/**
	 * A logger that helps identify this class' printouts.
	 */
	private static final Logger log = LoggerFactory.getLogger(PojoAspect.class);

	// ========================= DEPENEDENCIES ============================

	// ========================= IMPLEMENTATION: InitializingBean =========

	/**
	 * @throws Exception
	 * @see org.springframework.beans.factory.InitializingBean#afterPropertiesSet()
	 */
	public void afterPropertiesSet() throws Exception
	{
		if (log.isDebugEnabled())
		{
			log.debug("Initializing aspect");
		}
	}

	// ========================= IMPLEMENTATION: DisposableBean ===========

	/**
	 * @throws Exception
	 * @see org.springframework.beans.factory.DisposableBean#destroy()
	 */
	public void destroy()
	{
		if (log.isDebugEnabled())
		{
			log.debug("Shutting down aspect");
		}
	}

	// ========================= IMPLEMENTATION: FqeClient ===============

	/**
	 * @param jp
	 */
	public void beforeAdvice(final JoinPoint jp)
	{
		if (log.isDebugEnabled())
		{
			log.debug("Before-advice " + jp);
		}
	}

	/**
	 * @param jp
	 */
	public void afterAdvice(final JoinPoint jp)
	{
		if (log.isDebugEnabled())
		{
			log.debug("After-advice" + jp);
		}
	}

	// ========================= GETTERS & SETTERS =======================

}
