/*******************************************************************************
 * Source File: SimpleServiceImpl.java
 ******************************************************************************/
package edu.utah.further.examples.fuse_aop;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.beans.factory.InitializingBean;

/**
 * A simple POJO service implementation.
 * <p>
 * -----------------------------------------------------------------------------------<br>
 * (c) 2008-2009 FURTHeR Project, Health Sciences IT, University of Utah<br>
 * Contact: Dr. Scott Narus {@code <scott.narus@hsc.utah.edu>}<br>
 * Biomedical Informatics, 26 South 2000 East<br>
 * Room 5775 HSEB, Salt Lake City, UT 84112<br>
 * Day Phone: 1-801-213-3288<br>
 * -----------------------------------------------------------------------------------
 *
 * @author Oren E. Livne {@code <oren.livne@utah.edu>}</code>
 * @version Aug 4, 2009
 */
public class SimpleServiceImpl implements SimpleService, InitializingBean, DisposableBean
{
	// ========================= CONSTANTS =================================

	/**
	 * A logger that helps identify this class' printouts.
	 */
	private static final Logger log = LoggerFactory.getLogger(SimpleServiceImpl.class);

	// ========================= DEPENEDENCIES ============================

	// ========================= IMPLEMENTATION: InitializingBean =========

	/**
	 * @throws Exception
	 * @see org.springframework.beans.factory.InitializingBean#afterPropertiesSet()
	 */
	public void afterPropertiesSet() throws Exception
	{
		// If you want to make sure that this service is initialized without looking at
		// the FUSE log file, uncomment the following line.
		// System.err.println(getClass() + ": initializing");
		if (log.isDebugEnabled())
		{
			log.debug("Initializing");
		}
	}

	// ========================= IMPLEMENTATION: DisposableBean ===========

	/**
	 * @throws Exception
	 * @see org.springframework.beans.factory.DisposableBean#destroy()
	 */
	public void destroy()
	{
		if (log.isDebugEnabled())
		{
			log.debug("Shutting down");
		}
	}

	// ========================= IMPLEMENTATION: FqeClient ===============

	/**
	 * @param helloMessage
	 * @return
	 * @see edu.utah.further.examples.fuse_aop.SimpleService#sayHello(java.lang.String)
	 */
	@Advisable
	public String sayHello(final String helloMessage)
	{
		final String output = "Hello, " + helloMessage + "!";
		if (log.isInfoEnabled())
		{
			log.debug(output);
		}
		return output;
	}

	// ========================= GETTERS & SETTERS =======================

}
